``ecbxrate`` maintains a database of exchange rate data fetched from the
European Central Bank, and allows lookups both from the command line and via
its API.

See the documentation_ for more tails.

.. _documentation: http://ecbxrate.readthedocs.org/en/latest/
